@@ -17,33 +17,59 @@
 # ==================================================================== #
 
 globalVariables(c('abname',
+                  'Antibiotic',
+                  'Interpretation',
+                  'Percentage',
+                  'bind_rows',
+                  'element_blank',
+                  'element_line',
+                  'theme',
+                  'theme_minimal',
+                  'antibiotic',
+                  'antibiotics',
                   'atc',
                   'bactid',
+                  'C_chisq_sim',
                   'cnt',
-                  'Count',
-                  'Cum',
-                  'CumTot',
+                  'count',
+                  'counts',
+                  'cum_count',
+                  'cum_percent',
                   'date_lab',
                   'days_diff',
-                  'Fctlvl',
+                  'fctlvl',
                   'first_isolate_row_index',
+                  'Freq',
                   'fullname',
                   'genus',
                   'gramstain',
-                  'Item',
+                  'item',
                   'key_ab',
                   'key_ab_lag',
                   'key_ab_other',
+                  'labs',
+                  'median',
                   'mic',
+                  'MIC',
+                  'microorganisms',
                   'mocode',
                   'molis',
                   'n',
+                  'na.omit',
+                  'observations',
+                  'official',
                   'other_pat_or_mo',
+                  'Pasted',
                   'patient_id',
-                  'Percent',
                   'quantile',
+                  'R',
                   'real_first_isolate',
+                  'S',
+                  'septic_patients',
                   'species',
                   'umcg',
+                  'value',
+                  'values',
+                  'View',
                   'y',
                   '.'))
