@@ -13,7 +13,8 @@ test_that("MDRO works", {
   expect_equal(outcome %>% class(), c('ordered', 'factor'))
 
   # septic_patients should have these finding using Dutch guidelines
-  expect_equal(outcome %>% freq(toConsole = FALSE) %>% pull(Count), c(3, 21))
+  expect_equal(outcome %>% freq() %>% pull(count),
+               c(2, 14)) # 2 unconfirmed, 14 positive
 
   expect_equal(BRMO(septic_patients, info = FALSE), MDRO(septic_patients, "nl", info = FALSE))
 
